cosmpy.protos.ibc.core.client package — cosmpy documentation

# cosmpy.protos.ibc.core.client package

## Subpackages

- cosmpy.protos.ibc.core.client.v1 package
  - Submodules
  - cosmpy.protos.ibc.core.client.v1.client_pb2 module
  - cosmpy.protos.ibc.core.client.v1.client_pb2_grpc module
  - cosmpy.protos.ibc.core.client.v1.genesis_pb2 module
  - cosmpy.protos.ibc.core.client.v1.genesis_pb2_grpc module
  - cosmpy.protos.ibc.core.client.v1.query_pb2 module
  - cosmpy.protos.ibc.core.client.v1.query_pb2_grpc module
  - cosmpy.protos.ibc.core.client.v1.tx_pb2 module
  - cosmpy.protos.ibc.core.client.v1.tx_pb2_grpc module
  - Module contents

## Module contents